// Copyright 2023 Specter Ops, Inc.
//
// Licensed under the Apache License, Version 2.0
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.
//
// SPDX-License-Identifier: Apache-2.0

package utils

import (
	_ "embed"
	"fmt"
	"os"

	"github.com/specterops/bloodhound/cmd/api/src/config"
)

const (
	integrationTestConfigEnvironmentVarName = "INTEGRATION_CONFIG_PATH"
)

func LoadIntegrationTestConfig() (config.Configuration, error) {
	if cfgPath := os.Getenv(integrationTestConfigEnvironmentVarName); cfgPath != "" {
		return config.ReadConfigurationFile(cfgPath)
	} else {
		return config.Configuration{}, fmt.Errorf("required environment variable %s not found", integrationTestConfigEnvironmentVarName)
	}
}
